/*
 * Maxim Integrated Products
 * India Design Center
 *
 * Copyright (c) 2010 Maxim Integrated Products
 *
 * File: $URL: $
 *
 * Description: This file contains functionality to perform GET and POST on /networks/wifiscan resource
 *
 * Originators: Barry Smith
 *
 * $Id: $
 */
var wifiscan = {};
// Data structures
var adhocSecurityOptions = {
	"OPEN": 0,
	"WPANYONE": 4
};

var infraSecurityOptions = {
	"OPEN": 0,
	"WEP": 1,
	"WPAPSK": 2,
	"WPAPSK2": 3,
	"WPANYONE": 4/*,
	"WPAENT": 5,
	"WPAENT2": 6*/
};

var wifiMode = {
	"ADHOC_ZEROCONF": 0,
	"ADHOC_STATIC_DHCPD": 1,
	"INFRA_STATIC": 2,
	"INFRA_DHCPC": 3
};

var wifiSecurity = {
	"OPEN": 0,
	"WEP": 1,
	"WPAPSK": 2,
	"WPAPSK2": 3,
	"WPANYONE": 4,
	"WPAENT": 5,
	"WPAENT2": 6
};

var wifiEncryption = {
	"TKIP": 0,
	"AES": 1
};

var wifiSecurityEncryption = {
	"OPEN_NONE": 0,
	"WEP_SHARED": 1,
	"WPAPSK_TKIP": 2,
	"WPAPSK2_TKIP": 3,
	"WPAPSK_AES": 4,
	"WPAPSK2_AES": 5,
	"WPANYONE_TKIP_ADHOC": 6,
	"WPANYONE_AES_ADHOC": 7,
	"WPAENT_AES": 8,
	"WPAENT2_AES": 9,
	"WPAENT_TKIP": 10,
	"WPAENT2_TKIP": 11
};

var wifiPostResponse = {
	"SUCCESS" : 0,
	"WIFIMODE_INVALID_DATATYPE" : 1,
	"INVALID_SSID" : 2,
	"INVALID_KEY" : 3,
	"INVALID_SECURITY" : 4,
	"INVALID_DNS" : 5,
	"INVALID_IPADDRESS" : 6,
	"INVALID_NETMASK" : 7,
	"INVALID_GATEWAY" : 8,
	"DATABASE_ERROR" : 9,
	"UNKNOWN_ERROR" : 10
};
// END Data structures

wifiscan.ResponseCodes = {
	"SUCCESS": 0,
	"UNSUPPORTED_HTTP_METHOD": 1,
	"UNSUPPORTED_RETURN_TYPE": 2,
	"UNSUPPORTED_ATTRIBUTE": 3,
	"UNKNOWN_ATTRIBUTE": 4,
	"UNKNOWN_PROPERTY": 5,
	"MESSAGE_PARSE_ERROR": 6,
	"DATABASE_FAILURE": 7,
	"UNKNOWN_ERROR": 8,
	"INVALID_MODE": 9,
	"INVALID_SSID": 10,
	"INVALID_KEY": 11,
	"BAD_KEY_ENCRYPTION": 12,
	"INVALID_SECURITY": 13,
	"INVALID_IPADDRESS": 14,
	"INVALID_NETMASK": 15,
	"INVALID_GATEWAY": 16,
	"INVALID_PRIMARY_DNS": 17,
	"INVALID_SECONDARY_DNS": 18
};

wifiscan.ResponseStrings = ["Success",
                       "Incorrect http method for this resource",
                       "Unsupported return mime-type",
                       "Unsupported attribute encountered for this resource",
                       "Unknown attribute encountered for this resource",
                       "Unknown property encountered for this resource",
                       "Message parsing error",
                       "Database IO error",
                       "An unknown error was encountered",
                       "Invalid wifi mode",
                       "Invalid ssid",
                       "Invalid wifi key",
                       "Wifi key decryption failed",
                       "Invalid wifi security",
                       "Invalid ipaddress",
                       "Invalid netmask",
                       "Invalid gateway",
                       "Invalid primary dns",
                       "Invalid secondary dns"];

/**
 * @brief Performs a GET on the /networks/wifi resource
 */		
wifiscan.get = function() {
	$.ajax({
		beforeSend: function(xhrObj){
		    xhrObj.setRequestHeader("Accept","application/xml");
		    $("#btnWifiScan").attr("disabled",true);
	        //$("#wifiStatus").html("Searching for WIFI enabled devices...");
	        $("#imgwifistatus").show();
	        $("#wifilistLoader").show();
		    // Repostion the Wifi Configuration form in its container
		    $("#wifi_configure").appendTo("#wifi_container").hide();
		},
		async: true,
		url: "/cgi-bin/v1/networks/wifi?" + Math.random(),
		type: "GET",
		dataType: "xml",
		success: getSuccessHandler,
		error: function(XMLHttpRequest, textStatus, errorThrown) {
			$("#btnWifiScan").attr("disabled",false);
			handleError("/networks/wifi", "GET", XMLHttpRequest, textStatus);
		}
	});

	function getSuccessHandler(xml) {
				// Hide the loader		
				$("#btnWifiScan").attr("disabled",false);
				//$("#wifilistLoader").hide();				
				
				wifiLoaded(xml);													
			}
};

/**
 * @brief Perform a POST on the /networks/wifi resource
 */
var newWifiSsid;
var newWifiMode;
wifiscan.post = function(xml, mode, ssid) {
	var timer;
	var adhoc_to_infra = false;
	newWifiSsid = ssid;
	newWifiMode = mode;
	$.ajax({
		beforeSend: function(xhrObj){
			xhrObj.setRequestHeader("Content-Type","application/xml");
		    xhrObj.setRequestHeader("Accept","application/xml");
		    $("#wifiConnectStatus").html("Configuring wifi...");
		    $("#wifiSubmitLoader").show();
		    $("#button_apply_settings").attr("disabled",true);
		    
		    // Check if the user is going from Adhoc to Infra or vice-versa
		    adhoc_to_infra = (newWifiMode == wifiMode.INFRA_DHCPC || newWifiMode == wifiMode.INFRA_STATIC);
		},
		url: "/cgi-bin/v1/networks/wifi",
		type: "POST",
		dataType: "xml",
		data: xml,
		success: function(data) {
			//alert("Result Data: "+data);
			var networksNode = $(data).children("networks");
			var res = parseInt($(networksNode).children("res").attr("ul"));
			if(res != wifiPostResponse.SUCCESS) {
				//alert("An error was encountered: "+res);
				alert("Error: "+wifiscan.ResponseStrings[parseInt( res )]);
				$("#wifiSubmitLoader").hide();
				$("#button_apply_settings").attr("disabled",false);
			} else {
				$("#button_apply_settings").attr("disabled",false);
				$("#wifiSubmitLoader").hide();
				
				$("#wifi_configure").appendTo("#wifi_container").hide();
			    $("#divWifiList").html("");
			    $("#divWifiContainer").hide();
			    
			    if( adhoc_to_infra ) {
					//alert("WiFi router configured successfully!\nPlease connect to your router before continuing...");
					//alert(eval('tip_res.'+getCookieLanguage()+'["WiFi router configured successfully"]'));
					//$("#wifiStatus").html("Trying to connect your camera to "+newWifiSsid+"... Please make sure that your system is also connected to "+newWifiSsid+"...");
					// TODO Keep polling to check wifi status
					//$("#wifiConnectStatus").html("Restarting your Wifi Network... Please wait...");
					//timer = window.setTimeout(poll,2000);
				} else {
					//alert("Wifi network changed to Adhoc mode!\nPlease connect to your camera before continuing...");
					//$("#wifiStatus").html("Trying to connect to your camera...");
					// Repostion the Wifi Configuration form in its container
				}
			    
			    //$("#imgwifistatus").show();
			    //$("#wifilistLoader").show();
			    //timer = window.setTimeout(wifi.checkWifiStatus, 3000);
			}
		},
		error: function(XMLHttpRequest, textStatus, errorThrown) {
			$("#wifiSubmitLoader").hide();
			$("#button_apply_settings").attr("disabled",false);
			handleError("/networks/wifi", "POST", XMLHttpRequest, textStatus);
		}
	});
};

wifiscan.checkWifiStatus = function () {
	$.ajax({
		beforeSend: function(xhrObj){
		    xhrObj.setRequestHeader("Accept","application/xml");
		    //$("#wifiSubmitLoader").show();
		},
		timeout: 10000,
		url: "/cgi-bin/v1/networks/wifi?"+Math.random(),
		type: "GET",
		dataType: "xml",
		success: function(data, textStatus, XMLHttpRequest) {
			// Check for success
			var networksNode = $(data).children("networks");
			var res = $(networksNode).children("res").attr("l");

			if (res == 0) {
				$("#imgwifistatus").hide();
				$("#wifiStatus").html("Successfully connected to "+newWifiSsid);
				//$("#wifiConnectStatus").html("Restarting your Wifi Network... Please wait...");
			} else {
				//$("#wifiStatus").html("Server down "+timer);
				timer = window.setTimeout(wifi.checkWifiStatus,2000);
			}
		},
		error: function(XMLHttpRequest, textStatus, errorThrown) {
			timer = window.setTimeout(wifi.checkWifiStatus,2000);
		}
	});
};

wifiscan.encrypt = function (pass) {
	var rsa = new RSAKey();
	var modulus = linebrk(key.modulus, 64);
	rsa.setPublic(modulus, key.exponent);
	
	var ciphertext = rsa.encrypt(pass);
	if (ciphertext == null) {
		$("#wifiSubmitLoader").hide();
		$("#button_apply_settings").attr("disabled",false);
		return null;
	}
	return linebrk(hex2b64(ciphertext), 64);
};
