var motion = {};
motion.enable = 1;
motion.record = 0;
motion.beep = 0;
motion.roiThreshold = 80;
motion.roiPercent = 10;
motion.camType = 0;

motion.ResponseCodes = {
	"SUCCESS" : 0,
	"UNSUPPORTED_HTTP_METHOD" : 1,
	"UNSUPPORTED_RETURN_TYPE" : 2,
	"UNSUPPORTED_ATTRIBUTE" : 3,
	"UNKNOWN_ATTRIBUTE" : 4,
	"UNKNOWN_PROPERTY" : 5,
	"MESSAGE_PARSE_ERROR" : 6,
	"DATABASE_FAILURE" : 7,
	"UNKNOWN_ERROR" : 8,
	"INVALID_ROI_PERCENT" : 9,
	"INVALID_ROI_THRESHOLD" : 10,
	"INVALID_ENABLE" : 11,
	"INVALID_REGION" : 12,
	"FAILED_TO_TOGGLE_MOTION_TRIGGERS" : 13	
};

motion.ResponseStrings = [
		"Success",
		"Incorrect http method for this resource",
		"Unsupported return mime-type",
		"Unsupported attribute encountered for this resource",
		"Unknown attribute encountered for this resource",
		"Unknown property encountered for this resource",
		"Message parsing error",
		"Database IO error",
		"An unknown error was encountered",
		"Invalid ROI percent value",
		"Invalid threshold value",
		"Invalid motion enable",
		"Invalid motion region",
		"Database updated, but failed to enable/disable the motion trigger(s). Please make sure that your camera is on and streaming" ];

motion.currentCam = 0;
motion.minRoiThreshold = 0;
motion.maxRoiThreshold = 100;

motion.get = function(instance) {
	$.ajax( {
		beforeSend : function(xhrObj) {
			xhrObj.setRequestHeader("Accept", "application/xml");
			$("#radio_cam"+instance).attr("checked", true);
		},
		//url : "/cgi-bin/v1/triggers/motion/" + instance+"?"+Math.random(),
		url : "/cgi-bin/v1/triggers/motion/" + instance +"?"+Math.random(),
		type : "GET",
		async : false,
		dataType : "xml",
		success : getSuccessHandler,
		error : function(err, textStatus) {
			handleError("/triggers/motion", "GET", err, textStatus);
		}
	});

	function getSuccessHandler(xml) {

		var triggersNode = $(xml).children("triggers");
		var resultNode = $(triggersNode).children("res");

		if (resultNode.attr("ul") == undefined) {
			//alert("XML Error: No result node");
			return;
		}

		if (parseInt(resultNode.attr("ul")) != motion.ResponseCodes.SUCCESS) {
			//alert("Error! "	+ motion.ResponseStrings[parseInt(resultNode.attr("ul"))]);
			return;
		}

		var motionNode = $(triggersNode).children("motion");
		var enable = $(motionNode).children("enable").attr("b");
		if (enable != undefined)
		{
			motion.enable =  parseInt(enable,10);
		} 

		enable = $(motionNode).children("record").attr("b");
		if (enable != undefined)
		{
			motion.record = parseInt(enable,10);
		}

		enable = $(motionNode).children("beep").attr("b");
		if (enable != undefined)
		{
			motion.beep = parseInt(enable,10);
		}
		
		var roiThreshold = $(motionNode).children("roiThreshold").attr("ul");
		if (roiThreshold != undefined)
		{
			roiThreshold = 100-parseInt(roiThreshold*10/25,10);
			motion.roiThreshold = roiThreshold;
		}

		var roiPercent = $(motionNode).children("roiPercent").attr("ul");
		if (roiPercent != undefined)
		{
			motion.roiPercent = parseInt(roiPercent,10);
		}

		var camType = $(motionNode).children("camType").attr("ul");
		if (camType != undefined)
		{
			motion.camType = parseInt(camType,10);
		}
		
		var regionsNode = $(motionNode).children("regions");
		i = 0;
		$(regionsNode).children("region").each(function() {
			var x1 = parseInt($(this).attr("x1"),10);
			var y1 = parseInt($(this).attr("y1"),10);
			var x2 = parseInt($(this).attr("w"),10);
			var y2 = parseInt($(this).attr("h"),10);

			if (x1 > 0 || y1 > 0 || x2 > 0 || y2 > 0) {
				// Convert from macro units to units of 40x40
				/*
				 * x1 = Math.round( (x1*16)/40 ); y1 = Math.round( (y1*16)/40 );
				 * x2 = Math.round( (x2*16)/40 ); y2 = Math.round( (y2*16)/40 );
				 */
				//x1 = Math.round(x1 / macrosPerBlockHor);
				//y1 = Math.round(y1 / macrosPerBlockVer);
				//x2 = Math.round(x2 / macrosPerBlockHor);
				//y2 = Math.round(y2 / macrosPerBlockVer);

				regions[i][0] = x1 + 1;
				regions[i][1] = y1 + 1;
				regions[i][2] = x2 + regions[i][0] - 1;
				regions[i][3] = y2 + regions[i][1] - 1;
			}
			else
			{
                regions[i][0] = 0;
				regions[i][1] = 0;
				regions[i][2] = 0;
				regions[i][3] = 0; 
			}
			i++;
		});

		//motion.setValues();
	}
};

motion.put = function() {
	
	function serializeXML() {
		// showStatus('Applying motion changes ... please wait');

		var enable = $("#enablemotion").attr("checked") ? 1 : 0;
		var record = $("#enablerecord").attr("checked") ? 1 : 0;
		var beep   = $("#enablebeep").attr("checked") ? 1 : 0;
		var percent = $("#percent").val();
		var threshold = $("#threshold").val();
		threshold = parseInt((100-threshold)*25/10,10);

		var xml = '<?xml version="1.0"?>';
		xml += '<triggers><motion>';
		xml += '<enable b="' + enable + '"/>';
		xml += '<record b="' + record + '"/>';
		xml += '<beep b="' + beep + '"/>';
		xml += '<roiThreshold ul="' + threshold + '"/>';
		xml += '<roiPercent ul="' + percent + '"/>';
		xml += '<regions>';
		for (r = 0; r < maxAreas; r++) {
			if (regions[r][0] > 0 || regions[r][1] > 0 || regions[r][2] > 0
					|| regions[r][3] > 0) {
				var x1 = regions[r][0] - 1;
				var y1 = regions[r][1] - 1;
				var x2 = regions[r][2] - regions[r][0] + 1;
				var y2 = regions[r][3] - regions[r][1] + 1;

				// convert to macro units
				/*
				 * x1 = Math.round((x1*hsize)/16); y1 =
				 * Math.round((y1*vsize)/16); x2 = Math.round((x2*hsize)/16); y2 =
				 * Math.round((y2*vsize)/16);
				 */
				//x1 = Math.round(x1 * macrosPerBlockHor);
				//y1 = Math.round(y1 * macrosPerBlockVer);
				//x2 = Math.round(x2 * macrosPerBlockHor);
				//y2 = Math.round(y2 * macrosPerBlockVer);
				xml += '<region x1="' + x1 + '" y1="' + y1 + '" w="' + x2
						+ '" h="' + y2 + '" />';
			} else {
				xml += '<region x1="0" y1="0" w="0" h="0" />';
			}
		}
		xml += '</regions>';

		xml += '</motion></triggers>';

		return xml;
	}

	var xml = serializeXML();
	
	$.ajax( {
		beforeSend : function(xhrObj) {
			xhrObj.setRequestHeader("Accept", "application/xml");
			xhrObj.setRequestHeader("Content-Type", "application/xml");
			$("#L1406").show();
			$("#button_apply").attr("disabled", true);
			$("#L1406").css( {
				visibility : "visible"
			});			
			$("#L1406").html(eval('tip_res.'+getCookieLanguage()+'["Settings Updating"]'));
		},
		url : "/cgi-bin/v1/triggers/motion/"+ (motion.currentCam+1) + "?" + Math.random(),
		type : "PUT",
		data : xml,
		dataType : "xml",
		success : putSuccessHandler,
		error : function(err, textStatus) {
			$("#button_apply").attr("disabled", false);
			$("#L1406").hide();
			handleError("/triggers/motion", "PUT", err, textStatus);
		}
	});

	function putSuccessHandler(xml) {
		$("#button_apply").attr("disabled", false);
		$("#L1406").show();

		var triggersNode = $(xml).children("triggers");
		var resultNode = $(triggersNode).children("res");

		if (resultNode.attr("ul") == undefined) {
			//alert("XML Error: No result node");
			return;
		}

		if (parseInt(resultNode.attr("ul")) != motion.ResponseCodes.SUCCESS) {
			//alert("Error! "	+ motion.ResponseStrings[parseInt(resultNode.attr("ul"))]);
		} 
		else
		{
		    //motion.getValues();
			$("#L1406").html(eval('tip_res.'+getCookieLanguage()+'["Settings Update Ok"]'));
			//alert(eval('tip_res.'+getCookieLanguage()+'["Settings Update Ok"]'));
		}
	}
};

/*
motion.getValues = function() {

	motion.enable = $("#enablemotion").attr("checked") ? 1 : 0;
	motion.record = $("#enablerecord").attr("checked") ? 1 : 0;
	motion.beep = $("#enablerecord").attr("checked") ? 1 : 0;
	motion.roiThreshold=$("#threshold").val();
	motion.roiPercent  =$("#percent").val();

    //regions[motion.currentCam] = regions;
};
*/
motion.setValues = function() {

	$("#enablemotion").attr("checked", motion.enable==1);
	$("#enablerecord").attr("checked", motion.record==1);
	$("#enablebeep").attr("checked", motion.beep==1);
	$("#threshold").val(motion.roiThreshold);
	$("#percent").val(motion.roiPercent);
		
	showAreas();

	//if(getCookieLanguage()=="cn")
    {
       $("#enable_all").val(eval('button_res.'+getCookieLanguage()+'["Enable All"]'));
	   $("#disable_all").val(eval('button_res.'+getCookieLanguage()+'["Disable All"]'));
       $("#button_apply").val(eval('button_res.'+getCookieLanguage()+'["Apply"]'));
       $("#button_help").val(eval('button_res.'+getCookieLanguage()+'["Help Right"]'));
    } 

	if(motion.camType ==1 )
	{
       $("#enablemotion").attr("disabled", true);
	   $("#enablerecord").attr("disabled", true);
	   $("#enablebeep").attr("disabled", true);
	   $("#threshold").attr("disabled", true);
	   $("#percent").attr("disabled", true);

	   $("#enable_all").attr("disabled", true);
	   $("#disable_all").attr("disabled", true);
	   $("#button_apply").attr("disabled", true);
	}
	else
	{
       $("#enablemotion").attr("disabled", false);
	   $("#enablerecord").attr("disabled", false);
	   $("#enablebeep").attr("disabled", false);
	   $("#threshold").attr("disabled", false);
	   $("#percent").attr("disabled", false);

	   $("#enable_all").attr("disabled", false);
	   $("#disable_all").attr("disabled", false);
	   $("#button_apply").attr("disabled", false);
	}	
};
